function [b] = VBA_logisticReg(y0,X)
% This function runs a simple logistic regression using VBA
% function [b] = VBA_logisticReg(y0,X)
% The logistic regression model is written as:
% P(y=1|b) = sig(X*b)
% where X is the correpsonding design matrix and b are the regression
% parameters.
% Note that if y is not binary, then this function binarizes it (using a
% simple median split).
% IN:
%   - y0: vector of binary data
%   - X: design matrix
% OUT:
%   - b: estimated regression weights

M.g_fname = @g_logistic;
M.options.binomial = 1;
M.options.inG.X = X;
M.dim.n_phi = size(X,2);
if ~isequal(unique(y0),[0;1])
    my = median(y0);
    y = NaN(size(y0));
    y(y0>my) = 1;
    y(y0<my) = 0;
else
    y = y0;
end
[posterior,out] = VBA_main(y,M);
b = posterior.muPhi;

