function out = VBA_plotxy(x,y,n,ha,flagSEM)
% plots y as a function of x, where x has been binned into n bins
% function out = VBA_plotxy(x,y,n,ha)
% IN:
%   - x: px1 independent variable (will be binned)
%   - y: pxq dependent variables (q can be more than 1!)
%   - n: number of bins for x (default=8)
%   - ha: axis handle
%   - flagSEM: flag for SEM (as opposed to standard deviation ; default=1)
% OUT:
%   - out: a structure containing the following fields:
%       .mx: the bin centers
%       .my: E[y] for each x-bin
%       .sy: sem[y] for each x-bin (if flagSEM=1)
%       .he: errorbars' handles

try,flagSEM=~~flagSEM;catch,flagSEM=1;end
noplot = 0;
if exist('ha','var')
    if ~isempty(ha)
        try
            set(ha,'visible',get(ha,'visible'))
        catch
            hf = figure('color',[1 1 1]);
            ha = axes('parent',hf,'nextplot','add');
        end
    else
        noplot = 1;
    end
else
    hf = figure('color',[1 1 1]);
    ha = axes('parent',hf,'nextplot','add');
end
if size(y,2)==1
    col = zeros(1,3);
else
    col = getColors(size(y,2));
end
sleg = cell(size(y,2),1);
mx = NaN(n,1);
my = NaN(n,size(y,2));
sy = NaN(n,size(y,2));
for i=1:size(y,2)
    p = 0:(100/n):100;
    xb = prctile(x,p);
    for j=1:n
        ind = find(x>=xb(j)&x<=xb(j+1));
        mx(j) = nanmean(x(ind));
        my(j,i) = nanmean(y(ind,i));
        sy(j,i) = nanstd(y(ind,i));
        N(j,i) = length(ind);
        if flagSEM
            sy(j,i) = sy(j,i)./sqrt(N(j,i));
        end
    end
    if ~noplot
        he(i) = errorbar(mx,my(:,i),sy(:,i)+eps,'parent',ha,'color',col(i,:),'marker','.');
        sleg{i} = ['dependent variable #',num2str(i)];
    end
end
if ~noplot
    out.he = he;
    if size(y,2)>1
        legend(ha,sleg)
    end
end

out.mx = mx;
out.my = my;
out.sy = sy;
out.n = N;

