function [EPc,Eadm,Vadm] = getPc(z,beta,v0,m0,gamma,bias)
% approximates expected confidence level (after investing z)
% function [Pc,Eadm,Vadm] = getPc(z,beta,v0,m0,gamma,bias)
% IN:
%   - z: normalized amount of resource invested (0<z<1)
%   - beta: effort efficacy type #1
%   - v0: prior variance of value representations
%   - m0: prior mean of value representations
%   - gamma: effort efficacy type #2
%   - bias: overconfidence bias
% OUT:
%   - EPc: expected confidence level, ie E[Pc|z]
%   - Eadm: expected absolute difference btw updated value means
%   - Vadm: variance of absolute difference btw updated value means
% Note: if z=0, then EPc returns the current confidence level

v = 1./((1./mean(v0)) + beta.*z); % V[dv]
dm0 = -diff(m0); % initial dm
Eadm = myEabs2(dm0,2*gamma*z); % E[|dm|]
Vadm = abs(dm0).^2 + 2*gamma.*z - Eadm.^2; % V[|dm|]
a = 1/2;%0.5066; % !!! set to 0 to remove the variance term !!!
b = 3/4;%0.7527; % !!! This was neglected in Lee&Daunizeau (2020) !!!
lambda = pi./sqrt(6*v);
EPc = sig(bias+(lambda.*Eadm./sqrt(1+a*((lambda.^2).*Vadm).^b)));

% EPc = sig(bias+(pi.*Eadm./sqrt(6*(v+0.5.*Vadm))));


function Eax = myEabs2(mu,V)
% approximates E[|x|] from the 1st-order moment of the folded Normal d
t = mu./sqrt(V);
t(isnan(t)) = 0;
Eax = sqrt((2.*V)./pi).*exp(-0.5*t.^2) + mu.*(2*sig(pi*t./sqrt(3))-1);
