function [EPc,Eadm,Vadm] = getPc_dmu(z,beta,v0,dm0,gamma,bias)
% approximates E[confidence] (same as getPc.m but with dm0 instead of m0)
% function [EPc,Eadm,Vadm] = getPc_dmu(z,beta,v0,dm0,gamma,bias)
% IN:
%   - z: amount of invested resources
%   - beta: type #1 effort efficacy
%   - v0: prior variances over value representations
%   - dm0: difference in prior means over value representations
%   - gamma: type #2 effort efficacy
%   - bias: overconfidence bias
% OUT:
%   - EPc: expected confidence level after having invested z
%   - Eadm: expected absolute difference in value means (after z)
%   - variance over the absolute difference in value means (after z)

v = 1./((1./mean(v0)) + beta.*z); % V[dv]
Eadm = myEabs2(dm0,2*gamma*z); % E[|dm|]
Vadm = abs(dm0).^2 + 2*gamma.*z - Eadm.^2; % V[|dm|]
a = 1/2;%0.5066; % !!! set to 0 to remove the variance term !!!
b = 3/4;%0.7527; % !!! This was neglected in Lee&Daunizeau (2020) !!!
if v>eps
    lambda = pi./sqrt(6*v);
    EPc = sig(bias+(lambda.*Eadm./sqrt(1+a*((lambda.^2).*Vadm).^b)));
else
    EPc = sig(bias+(pi*Eadm./sqrt(6*(v+0.5*Vadm))));
end

function Eax = myEabs2(mu,V)
% approximates E[|x|] from the 1st-order moment of the folded Normal d
t = mu./sqrt(V);
t(isnan(t)) = 0;
Eax = sqrt((2.*V)./pi).*exp(-0.5*t.^2) + mu.*(2*sig(pi*t./sqrt(3))-1);